==> Xarm-1.2.7.tar.gz: Xarm-1.2.7/include/Xarm/MenuShell.h <==
/* $Id: MenuShell.h,v 1.2 1997/04/07 15:33:20 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_MENUSHELL_H_)
#define _XARM_MENUSHELL_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Shell.h>

class MenuShellClass : public OverrideShellClass {
 protected:
   MenuShellClass() {}
   virtual WidgetClass classPointer() { return xmMenuShellWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmMenuShell"; }
 public:
   void buttonFontList(XmFontList);
   XmFontList buttonFontList(); 
   XmFontList defaultFontList();
   void labelFontList(XmFontList);
   XmFontList labelFontList();
};

class MenuShell : public MenuShellClass {
 public:
   MenuShell(Widget w_parent, 
             ArgList arglist = NULL, 
             Cardinal cnt = 0,
             _XtString name = NULL);
   MenuShell(_XtString name, Widget w_parent);
   MenuShell(Widget w_parent, XarmArg &args, _XtString name);
};

#endif

==> Xarm-1.3.0.tar.gz: Xarm-1.3.0/include/Xarm/MenuShell.h <==
/* $Id: MenuShell.h,v 1.2 1997/04/07 15:33:20 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_MENUSHELL_H_)
#define _XARM_MENUSHELL_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Shell.h>

class MenuShellClass : public OverrideShellClass {
 protected:
   MenuShellClass() {}
   virtual WidgetClass classPointer() { return xmMenuShellWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmMenuShell"; }
 public:
   void buttonFontList(XmFontList);
   XmFontList buttonFontList() const;
   XmFontList defaultFontList() const;
   void labelFontList(const XmFontList);
   XmFontList labelFontList() const;
};

class MenuShell : public MenuShellClass {
 public:
   MenuShell(Widget w_parent, 
             ArgList arglist = NULL, 
             Cardinal cnt = 0,
             _XtString name = NULL);
   MenuShell(_XtString name, Widget w_parent);
   MenuShell(Widget w_parent, XarmArg &args, _XtString name);
};

#endif
